from .logger import LoggerObj
from .config import DMT_LOG_TEMPLATE, DMT_LOG_TIME_FORMAT, DMT_LOG_LEVEL, DMT_LOG_PATH

class LoggersClass:
    """Classe Singleton para gerenciar loggers globais."""
    _instance = None
    log_path = DMT_LOG_PATH

    def __new__(cls):
        """Garante que apenas uma instância de LoggersClass seja criada."""
        if cls._instance is None:
            cls._instance = super(LoggersClass, cls).__new__(cls)
            cls._instance.loggers = {}
        return cls._instance

    def add_logger(self, name: str, log_path: str = log_path, log_level: int = DMT_LOG_LEVEL, 
                   log_template: str = DMT_LOG_TEMPLATE, time_format: str = DMT_LOG_TIME_FORMAT) -> LoggerObj:
        """Adiciona um novo logger."""
        if name not in self.loggers:
            log_path = log_path or self.log_path
            self.loggers[name] = LoggerObj(name, log_path, log_level, log_template, time_format)
        return self.loggers[name]
    
    def get_logger(self, name: str) -> LoggerObj:
        """Retorna um logger existente ou cria um novo se não existir."""
        if name not in self.loggers:
            raise KeyError(f"Logger '{name}' não encontrado.")
        return self.loggers[name]

# Instanciando a classe Singleton globalmente
Loggers = LoggersClass()
